==> smartsheet_python_sdk-2.86.0-py2.py3-none-any.whl: smartsheet/models/web_content_widget_content.py <==
# pylint: disable=C0111,R0902,R0904,R0912,R0913,R0915,E1101
# Smartsheet Python SDK.
#
# Copyright 2017 Smartsheet.com, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"): you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from __future__ import absolute_import

from .enums import WidgetType
from .widget_content import WidgetContent
from ..types import *
from ..util import serialize
from ..util import deserialize


class WebContentWidgetContent(WidgetContent):
    """Smartsheet WebContentWidgetContent data model."""

    def __init__(self, props=None, base_obj=None):
        """Initialize the WebContentWidgetContent model."""
        super(WebContentWidgetContent, self).__init__(WidgetType.WEBCONTENT, base_obj)

        self._base = None
        if base_obj is not None:
            self._base = base_obj

        """Represents the WebContentWidgetContent object"""
        self._url = String()

        if props:
            deserialize(self, props)

        self.__initialized = True

    """Represents the WebContentWidgetContent object."""
    @property
    def url(self):
        return self._url.value

    @url.setter
    def url(self, value):
        self._url.value = value

    def to_dict(self):
        return serialize(self)

    def to_json(self):
        return json.dumps(self.to_dict())

    def __str__(self):
        return self.to_json()

==> smartsheet_python_sdk-3.0.2-py2.py3-none-any.whl: smartsheet/models/web_content_widget_content.py <==
# pylint: disable=C0111,R0902,R0904,R0912,R0913,R0915,E1101
# Smartsheet Python SDK.
#
# Copyright 2017 Smartsheet.com, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"): you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from __future__ import absolute_import

from ..types import String, json
from ..util import deserialize, serialize
from .enums import WidgetType
from .widget_content import WidgetContent


class WebContentWidgetContent(WidgetContent):
    """Smartsheet WebContentWidgetContent data model."""

    def __init__(self, props=None, base_obj=None):
        """Initialize the WebContentWidgetContent model."""
        super().__init__(WidgetType.WEBCONTENT, base_obj)

        self._base = None
        if base_obj is not None:
            self._base = base_obj

        # Represents the WebContentWidgetContent object
        self._url = String()

        if props:
            deserialize(self, props)

        self.__initialized = True

    @property
    def url(self):
        return self._url.value

    @url.setter
    def url(self, value):
        self._url.value = value

    def to_dict(self):
        return serialize(self)

    def to_json(self):
        return json.dumps(self.to_dict())

    def __str__(self):
        return self.to_json()
